.. Packaging Scientific Python documentation master file, created by
   sphinx-quickstart on Thu Jun 28 12:35:56 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Flounder Zipline-Sharadar Interface
===================================

The Flounder Zipline-Sharadar interface represents the Flounder extension
of the `Zipline <https://github.com/quantopian/zipline>`_ quantitative research platform for ingesting and loading
`Sharadar <https://www.quandl.com/publishers/SHARADAR>`_ data.

The current version provides consolidated access to daily prices,
fundamentals, and metadata of US stocks for selecting
tradable universes and running multiple factors within the Zipline pipeline.

.. toctree::
   :maxdepth: 1

   intro
   ingest
   building
   running


